@@ -2,10 +2,10 @@ __all__ = [
     'ImportancesTab',
     'ModelSummaryTab',
     'ContributionsTab',
+    'WhatIfTab',
     'ShapDependenceTab',
     'ShapInteractionsTab',
     'DecisionTreesTab',
-    'XGBoostTreesTab'
 ]
 
 import dash_html_components as html
@@ -117,6 +117,30 @@ class ContributionsTab(ExplainerComponent):
             self.contribs.layout()
         ])
 
+class WhatIfTab(ExplainerComponent):
+    def __init__(self, explainer, title="What if...", name=None):
+        """Tab showing individual predictions and allowing edits 
+            to the features...
+
+        Args:
+            explainer (Explainer): explainer object constructed with either
+                        ClassifierExplainer() or RegressionExplainer()
+            title (str, optional): Title of tab or page. Defaults to 
+                        "Individual Predictions".
+            name (str, optional): unique name to add to Component elements. 
+                        If None then random uuid is generated to make sure 
+                        it's unique. Defaults to None.
+        """
+        super().__init__(explainer, title, name)
+        self.tab_id = "whatif"
+        self.whatif = WhatIfComposite(explainer)
+        self.register_components(self.whatif)
+    
+    def layout(self):
+        return html.Div([
+            self.whatif.layout()
+        ])
+
 
 class ShapDependenceTab(ExplainerComponent):
     def __init__(self, explainer, title='Feature Dependence', name=None,
@@ -191,31 +215,6 @@ class DecisionTreesTab(ExplainerComponent):
         self.trees = DecisionTreesComposite(explainer)
         self.register_components(self.trees)
 
-    def layout(self):
-        return html.Div([
-            self.trees.layout()
-        ])
-
-
-class XGBoostTreesTab(ExplainerComponent):
-    def __init__(self, explainer, title="XGBoost Trees", name=None):
-        """Tab showing individual decision trees from xgboost model
-
-        Args:
-            explainer (Explainer): explainer object constructed with either
-                        ClassifierExplainer() or RegressionExplainer()
-            title (str, optional): Title of tab or page. Defaults to 
-                        'Decision Trees'.
-            name (str, optional): unique name to add to Component elements. 
-                        If None then random uuid is generated to make sure 
-                        it's unique. Defaults to None.
-        """
-        super().__init__(explainer, title, name)
-
-    
-        self.trees = XGBoostTreesComposite(explainer)
-        self.register_components(self.trees)
-
     def layout(self):
         return html.Div([
             self.trees.layout()
