@@ -26,8 +26,8 @@ class RegressionBaseExplainerTests(unittest.TestCase):
 
         self.explainer = RegressionExplainer(
                             model, X_test, y_test, r2_score,
-                            shap='tree',
-                            cats=['Sex', 'Cabin', 'Embarked'],
+                            cats=[{'Gender': ['Sex_female', 'Sex_male', 'Sex_nan']}, 
+                                                'Deck', 'Embarked'],
                             idxs=test_names, target='Fare', units='$')
 
     def test_explainer_len(self):
@@ -51,13 +51,13 @@ class RegressionBaseExplainerTests(unittest.TestCase):
         self.assertIsInstance(self.explainer.columns_ranked_by_shap(cats=True), list)
 
     def test_equivalent_col(self):
-        self.assertEqual(self.explainer.equivalent_col("Sex_female"), "Sex")
-        self.assertEqual(self.explainer.equivalent_col("Sex"), "Sex_female")
+        self.assertEqual(self.explainer.equivalent_col("Sex_female"), "Gender")
+        self.assertEqual(self.explainer.equivalent_col("Gender"), "Sex_female")
         self.assertIsNone(self.explainer.equivalent_col("random"))
 
     def test_get_col(self):
-        self.assertIsInstance(self.explainer.get_col("Sex"), pd.Series)
-        self.assertEqual(self.explainer.get_col("Sex").dtype, "object")
+        self.assertIsInstance(self.explainer.get_col("Gender"), pd.Series)
+        self.assertEqual(self.explainer.get_col("Gender").dtype, "object")
 
         self.assertIsInstance(self.explainer.get_col("Age"), pd.Series)
         self.assertEqual(self.explainer.get_col("Age").dtype, np.float)
@@ -83,7 +83,7 @@ class RegressionBaseExplainerTests(unittest.TestCase):
         self.assertIsInstance(self.explainer.shap_top_interactions("Age"), list)
         self.assertIsInstance(self.explainer.shap_top_interactions("Age", topx=4), list)
         self.assertIsInstance(self.explainer.shap_top_interactions("Age", cats=True), list)
-        self.assertIsInstance(self.explainer.shap_top_interactions("Sex", cats=True), list)
+        self.assertIsInstance(self.explainer.shap_top_interactions("Gender", cats=True), list)
 
     def test_permutation_importances_df(self):
         self.assertIsInstance(self.explainer.permutation_importances_df(), pd.DataFrame)
@@ -144,11 +144,11 @@ class RegressionBaseExplainerTests(unittest.TestCase):
 
     def test_pdp_result(self):
         self.assertIsInstance(self.explainer.get_pdp_result("Age"), pdpbox.pdp.PDPIsolate)
-        self.assertIsInstance(self.explainer.get_pdp_result("Sex"), pdpbox.pdp.PDPIsolate)
+        self.assertIsInstance(self.explainer.get_pdp_result("Gender"), pdpbox.pdp.PDPIsolate)
         self.assertIsInstance(self.explainer.get_pdp_result("Age", index=0), pdpbox.pdp.PDPIsolate)
-        self.assertIsInstance(self.explainer.get_pdp_result("Sex", index=0), pdpbox.pdp.PDPIsolate)
+        self.assertIsInstance(self.explainer.get_pdp_result("Gender", index=0), pdpbox.pdp.PDPIsolate)
         self.assertIsInstance(self.explainer.get_pdp_result("Age", X_row=self.explainer.X.iloc[[0]]), pdpbox.pdp.PDPIsolate)
-        self.assertIsInstance(self.explainer.get_pdp_result("Sex", X_row=self.explainer.X_cats.iloc[[0]]), pdpbox.pdp.PDPIsolate)
+        self.assertIsInstance(self.explainer.get_pdp_result("Gender", X_row=self.explainer.X_cats.iloc[[0]]), pdpbox.pdp.PDPIsolate)
 
     def test_get_dfs(self):
         cols_df, shap_df, contribs_df = self.explainer.get_dfs()
@@ -179,7 +179,7 @@ class RegressionBaseExplainerTests(unittest.TestCase):
         fig = self.explainer.plot_interactions("Age")
         self.assertIsInstance(fig, go.Figure)
 
-        fig = self.explainer.plot_interactions("Sex")
+        fig = self.explainer.plot_interactions("Gender")
         self.assertIsInstance(fig, go.Figure)
 
     def test_plot_shap_interactions(self):
@@ -227,17 +227,17 @@ class RegressionBaseExplainerTests(unittest.TestCase):
         fig = self.explainer.plot_shap_interaction_summary("Sex_female", topx=3)
         self.assertIsInstance(fig, go.Figure)
 
-        fig = self.explainer.plot_shap_interaction_summary("Sex", cats=True)
+        fig = self.explainer.plot_shap_interaction_summary("Gender", cats=True)
         self.assertIsInstance(fig, go.Figure)
 
     def test_plot_shap_dependence(self):
         fig = self.explainer.plot_shap_dependence("Age")
         self.assertIsInstance(fig, go.Figure)
 
-        fig = self.explainer.plot_shap_dependence("Sex")
+        fig = self.explainer.plot_shap_dependence("Gender")
         self.assertIsInstance(fig, go.Figure)
 
-        fig = self.explainer.plot_shap_dependence("Age", "Sex")
+        fig = self.explainer.plot_shap_dependence("Age", "Gender")
         self.assertIsInstance(fig, go.Figure)
 
         fig = self.explainer.plot_shap_dependence("Sex_female", "Age")
@@ -246,7 +246,7 @@ class RegressionBaseExplainerTests(unittest.TestCase):
         fig = self.explainer.plot_shap_dependence("Age", highlight_index=0)
         self.assertIsInstance(fig, go.Figure)
 
-        fig = self.explainer.plot_shap_dependence("Sex", highlight_index=0)
+        fig = self.explainer.plot_shap_dependence("Gender", highlight_index=0)
         self.assertIsInstance(fig, go.Figure)
 
     def test_plot_shap_contributions(self):
@@ -281,7 +281,7 @@ class RegressionBaseExplainerTests(unittest.TestCase):
         fig = self.explainer.plot_shap_interaction("Sex_female", "Age")
         self.assertIsInstance(fig, go.Figure)
 
-        fig = self.explainer.plot_shap_interaction("Sex", "Age")
+        fig = self.explainer.plot_shap_interaction("Gender", "Age")
         self.assertIsInstance(fig, go.Figure)
 
         fig = self.explainer.plot_shap_interaction("Age", "Sex_female", highlight_index=0)
@@ -291,10 +291,10 @@ class RegressionBaseExplainerTests(unittest.TestCase):
         fig = self.explainer.plot_pdp("Age")
         self.assertIsInstance(fig, go.Figure)
 
-        fig = self.explainer.plot_pdp("Sex")
+        fig = self.explainer.plot_pdp("Gender")
         self.assertIsInstance(fig, go.Figure)
 
-        fig = self.explainer.plot_pdp("Sex", index=0)
+        fig = self.explainer.plot_pdp("Gender", index=0)
         self.assertIsInstance(fig, go.Figure)
 
         fig = self.explainer.plot_pdp("Age", index=0)
